wurfl2python

Module wurfl2python |
[hide private]
[frames] | no frames]

# Module wurfl2python

source code

WURFL <wurfl.sourceforge.net> conversion utility

usage: wurfl2python.py [options] WURFL_XML_FILE

Version: 5.0.0a

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2004-2010, Armand Lynch

License: LGPL

Classes | [hide private]
| DeviceSerializer
| WurflPythonWriter

Functions | [hide private]
get_normalized_types(tree) | source code

Variables | [hide private]
| __doc__ = ``...``
| __contributors__ = ``'``Pau Aliagas <pau@newtral.org>``'``
| __url__ = ``'``http://celljam.net/``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      WURFL <wurfl.sourceforge.net> conversion utility

      usage: wurfl2python.py [options] WURFL_XML_FILE
      """